@@ -35,7 +35,10 @@ class GraphFormatter(base.SingleFormatter, metaclass=abc.ABCMeta):
         # so disable it (currently we don't have real multigraphs)
         self._reformat(data)
 
-        if nx.__version__ >= '2.0':
+        if nx.__version__ >= '3.0':
+            graph = json_graph.node_link_graph(
+                data, name='graph_index')
+        elif nx.__version__ >= '2.0':
             graph = json_graph.node_link_graph(
                 data, attrs={'name': 'graph_index'})
         else:
@@ -70,9 +73,9 @@ class GraphFormatter(base.SingleFormatter, metaclass=abc.ABCMeta):
     @staticmethod
     def _list2str(node):
         for k, v in node.items():
-            if type(v) == list:
+            if type(v) is list:
                 node[k] = str(v)
-            if type(v) == str and ":" in v:
+            if type(v) is str and ":" in v:
                 node[k] = '"' + v + '"'
 
     @abc.abstractmethod
